@@ -1,16 +1,13 @@
 package CDB_File;
 
 use strict;
-use Carp;
-use vars qw($VERSION @ISA @EXPORT_OK);
 
-use DynaLoader ();
+use XSLoader ();
 use Exporter ();
 
-@ISA = qw(Exporter DynaLoader);
-@EXPORT_OK = qw(create);
-
-$VERSION = '0.97';
+our @ISA = qw(XSLoader Exporter);
+our $VERSION = '0.98';
+our @EXPORT_OK = qw(create);
 
 =head1 NAME
 
@@ -41,7 +38,7 @@ or
 =head1 DESCRIPTION
 
 B<CDB_File> is a module which provides a Perl interface to Dan
-Berstein's B<cdb> package:
+Bernstein's B<cdb> package:
 
     cdb is a fast, reliable, lightweight package for creating and
     reading constant databases.
@@ -324,10 +321,11 @@ Now maintained by Matt Sergeant, <matt@sergeant.org>
 
 =cut
 
-bootstrap CDB_File $VERSION;
+XSLoader::load ('CDB_File', $VERSION);
 
 sub CLEAR {
-	croak "Modification of a CDB_File attempted"
+	require Carp;
+    Carp::croak ("Modification of a CDB_File attempted");
 }
 
 sub DELETE {
